# TOPSIS Rank 

This package will help you calculate TOPSIS rank quickly.

## How to install it?

## On Windows:

```
pip install TOPSIS-Aastha-101903306
```

## On Linux:

```
sudo pip3 install TOPSIS-Aastha-101903306
```

## How to use it?

topsis(DF, weights, impacts):

Parameters:
    DF : pandas dataframe which contains 3 or more than 3 columns. 
    weights : numeric values 
    impacts : + or - 

To run the file, enter 5 command line arguments:
1. The name of the current file
2. Input file containing data (either .csv or .xlsx)
3. A string containing weights
4. A string containg impacts (either + or -)
5. Name of output file

     


